# Assumptions and caveats log

This log contains a list of assumptions and caveats used in this analysis.

## Definitions

Assumptions are red, amber or green (RAG) rated according to the following definitions for quality and impact[^1]:

| RAG rating | Assumption quality | Assumption impact |
|------------|--------------------|-------------------|
| GREEN | Reliable assumption, well understood and/or documented; anything up to a validated & recent set of actual data. | Marginal assumptions; their changes have no or limited impact on the outputs.  |
| AMBER | Some evidence to support the assumption; may vary from a source with poor methodology to a good source that is a few years old. | Assumptions with a relevant, even if not critical, impact on the outputs. |
| RED   | Little evidence to support the assumption; may vary from an opinion to a limited data source with poor methodology. | Core assumptions of the analysis; the output would be drastically affected by their change. |

[^1]: With thanks to the Home Office Analytical Quality Assurance team for these definitions.

## Assumptions and caveats

Assumptions and caveats last updated: { current_date }

This analysis contains the following assumptions and caveats:

{ assumptions }

{ caveats }
